@@ -2,7 +2,7 @@
 #'
 #' The \code{plot()} method for the \code{bayestestR::bayesfactor_parameters()} function.
 #'
-#' @param point_size Size of point-geoms.
+#' @param size_point Size of point-geoms.
 #' @param rope_alpha Transparency level of ROPE ribbon.
 #' @param rope_color Color of ROPE ribbon.
 #' @param show_intercept Logical, if \code{TRUE}, the intercept-parameter is included
@@ -16,7 +16,7 @@
 #'
 #' @importFrom rlang .data
 #' @export
-plot.see_bayesfactor_parameters <- function(x, point_size = 2, rope_color = "#0171D3", rope_alpha = .2, show_intercept = FALSE, ...) {
+plot.see_bayesfactor_parameters <- function(x, size_point = 2, rope_color = "#0171D3", rope_alpha = .2, show_intercept = FALSE, ...) {
   plot_data <- attr(x, "plot_data")$plot_data
   d_points <- attr(x, "plot_data")$d_points
   hypothesis <- attr(x, "hypothesis")
@@ -73,7 +73,7 @@ plot.see_bayesfactor_parameters <- function(x, point_size = 2, rope_color = "#01
       )
   } else {
     p <- p +
-      geom_point(data = d_points, size = point_size, pch = 21, colour = null_point_outline, stroke = 1)
+      geom_point(data = d_points, size = size_point, pch = 21, colour = null_point_outline, stroke = 1)
   }
 
   p
